Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Devices map[string]*DeviceConfig `yaml:"devices,omitempty"`
}
Config provides means of reading the configuration file
type DeviceConfig ¶
type DeviceConfig struct {
OSVersion OSVersion
Host string
Port int `yaml:"port,omitempty"`
Username string `yaml:"username"`
KeyFile string `yaml:"key_file,omitempty"`
Password string `yaml:"password,omitempty"`
ConnectTimeout int `yaml:"connect_timeout,omitempty"`
CommandTimeout int `yaml:"command_timeout,omitempty"`
EnabledCollectors []string `yaml:"enabled_collectors,flow"`
Interfaces []string `yaml:"interfaces,flow"`
}
DeviceConfig is used to read device configuration from the config file DeviceConfig describe how to connect to a remote device and what metrics to extract from the remote device.
type OSVersion ¶
type OSVersion int
OSVersion is a type to refere to the remote device's operating system. Different parsers / commands might be needed due to differences in the Cisco CLI.
func GetAllOsVersions ¶ added in v1.0.3
func GetAllOsVersions() []OSVersion
GetAllOsVersions returns all known and valid os version
Click to show internal directories.
Click to hide internal directories.