Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCollector ¶
NewCollector returns a new instace of interface.Collector.
func Parse ¶
func Parse(sshCtx *connector.SSHCommandContext, interfaces chan *Interface, done chan struct{})
Parse parses cli output and tries to find interfaces with related stats
Types ¶
type Collector ¶
type Collector struct {
}
Collector gathers counters for remote device's interfaces.
func (*Collector) Collect ¶
func (c *Collector) Collect(ctx *collector.CollectContext)
Collect implements the collector.Collector interface's Collect function
func (*Collector) Describe ¶
func (*Collector) Describe(ch chan<- *prometheus.Desc)
Describe implements the collector.Collector interface's Describe function
type Interface ¶
type Interface struct {
Name string
MacAddress string
Description string
AdminStatus string
OperStatus string
InputErrors float64
OutputErrors float64
InputDrops float64
OutputDrops float64
InputBytes float64
OutputBytes float64
Speed string
}
Interface represents a network interface on the remote device
Click to show internal directories.
Click to hide internal directories.