Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCollector ¶
NewCollector returns a new aaa.Collector instance.
Types ¶
type Collector ¶
type Collector struct {
}
Collector gathers metrics from the MPLS forwarding table from the remote device by running `show mpls memory` and `show mpls forwarding-table`
func (*Collector) Collect ¶
func (c *Collector) Collect(ctx *collector.CollectContext)
Collect implements the collector.Collector interface's Collect function
func (*Collector) Describe ¶
func (*Collector) Describe(ch chan<- *prometheus.Desc)
Describe implements the collector.Collector interface's Describe function
type LabelStatistic ¶
type LabelStatistic struct {
LocalLabel string
OutgoingLabel string
PrefixOrTunnelID string
OutgoingInterface string
NextHop string
BytesLabelSwitched float64
}
LabelStatistic refers to one entry in the stdout of `show mpls forwarding-table`.
type MemoryStatistic ¶
MemoryStatistic refers to one entry in the stdout of `show mpls memory`.
Click to show internal directories.
Click to hide internal directories.